// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include <vector>
#include "OmDs9ImageDlg.h"
#include <qapplication.h>
#include <qpushbutton.h>
#include <qdialog.h>
#include "OmSourceVersionNo.h"
#include "OmSourceLog.h"
#include "OmSourceGroupBox.h"
#include "OmSourceLabel.h"

#include "OmSourceParameters.h"
#include "OmSourceButton.h"
#include "AngleFormatter.h"
#include <qtable.h>
#include <qstring.h>
#include <qtooltip.h>
#include <qdesktopwidget.h>
#include <qlayout.h>
#include <qprinter.h> 
#include <qpainter.h>
#include <qfont.h> 
#include <qtimer.h>
#include <qpaintdevicemetrics.h> 
#include <iostream>
#include "OmSourceBrowser.h"
#include "OmImageDisplay.h"      

/********************************************************************************
 * Dialog for running omdetect- allows you to change the parameters nsigma
 * and minsignificance.          
 *
 *******************************************************************************/

Ds9ImageDlg::Ds9ImageDlg(QWidget *parent) : QDialog(parent, "", true)
{
    int xPos = 20;
    int yPos = 20;
   
    QFont font( "Times", 16, QFont::Bold );
   

    OmSourceLabel* label = new OmSourceLabel(this, font,
	  "Change the image appearance by changing the ds9 settings Scale & Color", 
          xPos, yPos); 
    label->setFrameStyle( QFrame::Panel | QFrame::Sunken );
    
    xPos = 50;
    yPos = label->geometry().bottom() + 20;;
    
    OmSourceButton* okButton = new OmSourceButton(this, "OK", xPos, yPos, 80, 30);
    QToolTip::add(okButton, "Click here to save the ds9 image settings");
    //    okButton->move((width() - okButton->width()) / 2, okButton->geometry().top());
    connect(okButton, SIGNAL( clicked() ), this, SLOT( okay() ));
 
    xPos = okButton->geometry().right();
    OmSourceButton* cancelButton = new OmSourceButton(this, "Cancel", xPos, yPos, 80, 30);
    QToolTip::add(cancelButton, "Click here to disregard the new ds9 image settings");
    connect(cancelButton, SIGNAL( clicked() ), this, SLOT( cancel() ));
  
    //    resize(250, 300);
  
   
    QDesktopWidget *d = QApplication::desktop();  // Gives the screen height and width 
 
    //    move((d->width() - width()) / 2, d->height() - height() - 10);    
    move((d->width() - width()) / 2, 0);    


    QTimer *timer = new QTimer(this);
    connect( timer, SIGNAL(timeout()), this, SLOT(displayDs9Image()) );
    timer->start( 2000, TRUE ); // 2 seconds single-shot timer
    



};
void Ds9ImageDlg::displayDs9Image()
{

    if (OmSourceBrowser::_display)
    {         
        OmSourceBrowser::_display->down();
        delete  OmSourceBrowser::_display;
    }
    OmSourceBrowser::_display = new OmImageDisplay();


    OmSourceBrowser::_display->displayImage(OmSourceBrowser::_imageFileName);
          
    OmSourceBrowser::_display->send("zoom to fit frame");
    OmSourceBrowser::_display->send("scale zscale");
    OmSourceBrowser::_display->send("scale linear");
    OmSourceBrowser::_display->send("cmap heat");






}

/****************************************************************
*
****************************************************************/
void Ds9ImageDlg::okay()
{
  //    char command[100];
  //    sprintf(command, "saveas png %s", OmSourceBrowser::_ds9ImageFile);

 
  //    OmSourceBrowser::_display->send(command);

 

    //  OmSourceBrowser::_display->send("hide");

   OmSourceBrowser::_display->down();
   delete OmSourceBrowser::_display;
   OmSourceBrowser::_display = 0;

 

   
    accept();
}
/***********************************************************
*
**********************************************************/
void Ds9ImageDlg::cancel()
{


    OmSourceBrowser::_display->down();
    delete OmSourceBrowser::_display;
    OmSourceBrowser::_display = 0;

 
 

   
    reject();




}




