// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      OmProgressDialog.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Sep 17 14:05:15 CEST 2002
// Usage:     -
// Info:      -

#include "OmProgressDialog.h"
#include <qprogressdialog.h>
#include <qpushbutton.h>
#include <qapplication.h>
#include "OmSourceVersionNo.h"
#include <qdatetime.h>
#include <iostream>
#include<cstring>
OmProgressDialog::OmProgressDialog(const std::string& text, int steps)
  : _impl(0)
{
 

  _impl = new QProgressDialog ( QString(text.c_str()), QString("Cancel"), steps);
   
  _impl->setCancelButton((QPushButton*)0);
  _impl->setAutoReset(true);
  _impl->setAutoClose(true);
  _impl->setLabelText(text.c_str());
  _impl->setTotalSteps(steps);
  _impl->show();
  _impl->setProgress(0);
   qApp->processEvents();
   QDateTime date = QDateTime::currentDateTime();
 
  _impl->setCaption(omsourceVersionNo()+QString("  ")+date.toString());  
  

  _impl->setGeometry(200, 200, 350, 80);

}


OmProgressDialog::~OmProgressDialog()
{
  
    delete _impl;


   qApp->processEvents();
 

}


void OmProgressDialog::setText(const std::string& text)
{
  //    QFont serifFont( "Times", 20, QFont::Bold );
   
  //  _impl->setFont(serifFont);


  _impl->setLabelText(text.c_str());  


  qApp->processEvents();
}


void OmProgressDialog::setProgress(int p)
{
  if (p < 0) return;
  _impl->setProgress(p);
  qApp->processEvents();
}


int OmProgressDialog::progress() const
{
  return _impl->progress();
}


int OmProgressDialog::totalSteps() const
{
  return _impl->totalSteps();
}


#include <Handle.h>
#include <f90cxx.h>

F90PROCDEF(Handle<OmProgressDialog>, omprogress_mod_new)(char* txt, int* steps, int txtlen)
{
  return new OmProgressDialog(std::string(txt, txtlen), *steps);
}
F90PROCDEF(void,omprogress_mod_delete)(Handle<OmProgressDialog>& h)
{
  delete h.addressOfObject();
}

F90PROCDEF(void, omprogress_mod_setlabel)(Handle<OmProgressDialog>& h, char* txt, int txtlen)
{
  h.addressOfObject()->setText(std::string(txt, txtlen));
}
F90PROCDEF(void, omprogress_mod_setprogress)(Handle<OmProgressDialog>& h, int* steps)
{
  h.addressOfObject()->setProgress(*steps);
}
F90PROCDEF(int ,omprogress_mod_progress)(const Handle<OmProgressDialog>&  h)
{
  return h.addressOfObject()->progress();
}
F90PROCDEF(int ,omprogress_mod_totalsteps)(const Handle<OmProgressDialog>& h)
{
  return h.addressOfObject()->totalSteps();
}







