// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#include <qtooltip.h>
#include <qstring.h>
#include <qlineedit.h>
#include <qwidget.h>
#include "OmSourceEdit.h"
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include<cstdlib>

/*************************************************************************
*
*
*************************************************************************/
OmSourceEdit::OmSourceEdit(QWidget *parent, QString title, 
       int x, int y, int height, QString help) :
       QLineEdit(title, parent)
{
    
    QFont f = font();
   
   
    QFontMetrics fm( f );
 
    int pixelWidth = fm.width(title ) + 3;

       
    setGeometry(x, y, pixelWidth + 2, height);


   
    setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
    //    setPaletteBackgroundColor(QColor(255, 0, 0));    
    //    setPaletteBackgroundColor(QColor(0, 0, 255));    


    setReadOnly(true);




    //    setPaletteBackgroundColor(QColor(156, 156, 156));    

    if (help)   
        QToolTip::add(this, help);

};
/*************************************************************************
*
*
*************************************************************************/
OmSourceEdit::OmSourceEdit(QWidget *parent, QString title, 
       int x, int y, int width, int height, QString help) :
       QLineEdit(title, parent)
{
    
   
   
    setGeometry(x, y, width, height);
   setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
     

    //    setFrameStyle( QFrame::Panel | QFrame::Raised );
   //    setFrameStyle( QFrame::Panel | QFrame::Sunken );
   
    //    setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
    
    //    setPaletteBackgroundColor(QColor(0, 0, 255));    
    //    setPaletteBackgroundColor(QColor(156, 156, 156));    

    if (help)   
        QToolTip::add(this, help);

};
/*************************************************************************
*
*
*************************************************************************/

void OmSourceEdit::setText(const QString &text)
{
    QFont f = font();
   
   
    QFontMetrics fm( f );
 
    int pixelWidth = fm.width(text ) + 10;

       
    setGeometry(x(), y(), pixelWidth, height());

    QLineEdit::setText(text);
};

/*************************************************************************
*
*
*************************************************************************/

void OmSourceEdit::setValue(const double number, const int width, const int ndec)
{

    _fNumber = number;
    QString text;
    text.sprintf("%*.*f", width, ndec,number);

    QFont f = font();
   
   
    QFontMetrics fm( f );
 
    int pixelWidth = fm.width(text ) + 10;

       
    setGeometry(x(), y(), pixelWidth , height());

    QLineEdit::setText( text );
};

/*******************************************************************
*
*
*******************************************************************/
void OmSourceEdit::setValue(const int number, const int width)
{

    _iNumber = number;
    QString text;
    text.sprintf("%*d", width, number);

    QFont f = font();
   
   
    QFontMetrics fm( f );
 
    int pixelWidth = fm.width(text ) + 10;

       
    setGeometry(x(), y(), pixelWidth, height());

    QLineEdit::setText( text );
};







 
