// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#ifndef OmSourceProcessDlg_h
#define OmSourceProcessDlg_h
#include <qapplication.h>

#include <qdialog.h>
#include <qstring.h>
#include <qcheckbox.h>
class QSpinBox;


#include "OmSourceLog.h"
#include "OmImageDisplay.h"
#include "OmSourceVersionNo.h"


class ExtractionRegion;

class QLabel;

struct ExtractionParameters;
class OmGrismProcess
{
 public:
  OmGrismProcess() {};
  virtual ~OmGrismProcess() {};
  virtual bool runProcess() = 0;


};
/****************************************************
 * Process to create grism source list
 ***************************************************/

class OmGrismProcess1 : public OmGrismProcess
{
 public:
  OmGrismProcess1(int size, float *yZero, float *xFirst, float *x1, float *x2, float *y1, float *y2, 
         ExtractionRegion* region, bool centroidyZero = true, 
         bool centroidxFirst = true, ExtractionParameters *extractionParameters = 0) :
    _size(size), _yZero(yZero), _xFirst(xFirst), _x1(x1), _x2(x2), _y1(y1), _y2(y2),  
    _extractionRegion(region), _centroidyZero(centroidyZero),
    _centroidxFirst(centroidxFirst),  _extractionParameters(extractionParameters)        {};
  virtual ~OmGrismProcess1() {};
 private:
  virtual bool runProcess();
       
 private:

  int _size;
  float *_yZero, *_xFirst;
  float *_x1, *_x2;
  float *_y1, *_y2;
 
  ExtractionRegion* _extractionRegion;     
  bool _centroidyZero, _centroidxFirst;
  ExtractionParameters *_extractionParameters;
};

/****************************************************
 * Process to recompute source parameters
 ***************************************************/
class OmGrismProcess2 : public OmGrismProcess
{
 public:

  OmGrismProcess2(ExtractionRegion* region) : _extractionRegion(region)  {};

 
 
  virtual ~OmGrismProcess2() {};
 private:
   
  virtual bool runProcess() {return true;};
       
 private:

  //  int _sourceNo;
  ExtractionRegion* _extractionRegion;
};

/****************************************************
 * Process to create a source-list
 ***************************************************/
class OmGrismProcess3 : public OmGrismProcess
{
 public:
  OmGrismProcess3() {};
 
  virtual ~OmGrismProcess3() {};
 private:
  virtual bool runProcess(); 
       
 private:

 
 
};



/****************************************************
 * Process to create grism source list
 ***************************************************/

class OmGrismProcess4 : public OmGrismProcess
{
 public:
  OmGrismProcess4(float xZero, float yZero,
                  float centralWidth,  
                  float leftOffset, float leftWidth,
                  float rightOffset, float rightWidth,
                  int binSize, 
                  ExtractionParameters *extractionParameters = 0) :
    _xZero(xZero), _yZero(yZero), _centralWidth(centralWidth),
    _leftOffset(leftOffset), _leftWidth(leftWidth),
    _rightOffset(rightOffset), _rightWidth(rightWidth),
    _binSize(binSize),
_extractionParameters(extractionParameters)        {};
  virtual ~OmGrismProcess4() {};
 private:
  virtual bool runProcess();
       
 private:
   
  float _xZero, _yZero;
  float _centralWidth;
  float _leftOffset, _leftWidth;
  float _rightOffset, _rightWidth;
  int _binSize; 
  ExtractionParameters *_extractionParameters;
};












/**************************************************
 *
 *************************************************/

class ProcessDlg : public QDialog
{
    Q_OBJECT
     
 private slots:
    

    void runProcess();    
 
    void pause();  
     
      public:
    ProcessDlg(QWidget *parent, OmGrismProcess *process, 
	       QString caption = QString::null);
  
 private:
   
    OmGrismProcess *_process;   
    QString _caption;
    QLabel *_label;   


};

#endif







