// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#ifndef UTILITY_H
#define UTILITY_H
#include <iostream>
#include <cstdlib>
#include <ctime>

/*********************************************
* Class Time
*********************************************/
class Time
{ 
   private:

        time_t startTime;
        time_t currentTime;
    public:
        void Initialise() 
        {
	  time(&startTime);
        };

        Time() {Initialise();};
        float GetTimeDiff()
        {
            time(&currentTime);
	    return difftime(currentTime, startTime);
  
        };
  
}; 

/********************************************
* class Error
********************************************/
class Error
{
    public:
        Error(char *message) 
        {
	    std::cout << "**********************************\n";
            std::cout << message << std::endl;
            std::cout << "**********************************\n";
	};
};     



/**********************************************
* int Locate                                 *
**********************************************/
//template <class kind>
int Locate(float *xx, int n, 
                     float x, int  jl = 0);

/*********************************************
 * Class AnySort - sorts anything
 ********************************************/
template <class T>
class AnySort
{
private:
    static int Compare(const void *point1, const void *point2)
    {
        T *p1 = (T *)point1;
        T *p2 = (T *)point2;

        if (*p1 > *p2) return 1;
        if (*p1 < *p2) return -1;
        return 0;
    }
public: 
    AnySort() {};
    static void Sort(size_t size, T *data)
    {
      
        qsort(data, size, sizeof(T), AnySort::Compare);
      
    };
};

 
float Random();


int Maximum(int a, int b);

int Minimum(int a, int b);



/*********************************************
* Mimimum
**********************************************/
template <class kind1>
kind1 Minimum(kind1 *arrayPtr);

/*********************************************
* Mamimum
**********************************************/
template <class kind1>
kind1 Maximum(kind1 *arrayPtr);

/*********************************************
* Sum
**********************************************/
template <class kind1>
double Sum(kind1 *arrayPtr);


/******************************************
* class Lagrange - Interpolation
*******************************************/
template <class kind>
class Lagrange
{
private:
    kind* x;
    kind* y;
    int n;
public:
    Lagrange() : x(NULL), y(NULL), n(0) {};
    Lagrange(int n, kind x[], kind y[]);
    void SetData(int n, kind x[], kind y[]);
   ~Lagrange() {delete [] x; delete [] y;};
    kind Interpolate(kind x);

};


/*********************************************
* GasDev - Returns a random Gaussian deviate
*********************************************/
float Gasdev();
#endif




